#
# spec file for package gfan
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gfan
Version:        0.6.2
Release:        bp155.3.59
Summary:        Calculation of Gröbner fans
License:        GPL-2.0-only
Group:          Productivity/Scientific/Math
URL:            http://home.imf.au.dk/jensen/software/gfan/gfan.html

Source:         http://home.imf.au.dk/jensen/software/gfan/%name%version.tar.gz
Patch1:         gfan-automake.diff
Patch2:         gfan-warnings.diff
Patch3:         cddlib.patch
Patch4:         gfan-odr.patch
BuildRequires:  automake
BuildRequires:  cddlib-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
%define with_pdf 1
%if 0%{?with_pdf}
BuildRequires:  texlive-latex
%if 0%{?suse_version} >= 1230
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-bibtex
BuildRequires:  texlive-cm-super
BuildRequires:  texlive-dvips
BuildRequires:  texlive-ntgclass
BuildRequires:  texlive-ulem
%if 0%{?suse_version} > 1230
BuildRequires:  tex(english.ldf)
%endif
%endif
%endif

%description
Gfan is a software package for computing Gröbner fans and tropical
varieties. These are polyhedral fans associated to polynomial ideals.

%prep
%autosetup -p1 -n %name%version

%build
autoreconf -fi
export CXXFLAGS="%optflags -Wno-sign-compare -Wno-reorder -Wno-unused -Wno-comment -Wno-misleading-indentation -std=gnu++11"
%configure
make %{?_smp_mflags} V=1
%if 0%{?with_pdf}
make -C doc %{?_smp_mflags}
%endif

%install
b="%buildroot"
%make_install
for i in $(src/gfan _list | grep ^gfan_); do
	ln -s gfan "$b/%_bindir/$i"
done

%files
%_bindir/gfan*
%license COPYING
%doc examples
%if 0%{?with_pdf}
%doc doc/manual.pdf
%endif

%changelog
* Tue Jul 13 2021 Alois Wohlschlager <alois1@gmx-topmail.de>
- Add gfan-odr.patch: A patch to fix ODR violations, which were
  causing segfaults in the respective programs with LTO enabled.
* Sat Sep 19 2020 Jan Engelhardt <jengelh@inai.de>
- Add cddlib.patch
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Specfile modernization.
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 0.6.2
  * Improved mixed volume computation, improved Gröbner basis
    implementation.
  * New tropical starting cone algorithm, resultant fan
    algorithms, tropical hypersurface reconstruction algorithm,
    tropical basis detection (in _tropicalintersection -t was
    replaced by --tropicalbasistest)
  * Stable intersection of tropical cycles (_fancommonrefinement
  - -stable)
  * Better implementation of the field of rational functions).
- Delete gfan-format.diff, gfan-returns.diff,
  gfan-remove-debug-code.diff (fixed upstream)
- Add gfan-warnings.diff
* Thu Jun 16 2016 jengelh@inai.de
- Add missing post and postun sections for ldconfig
- Build with std=gnu++98 because the code has not been written
  with C++11's std::rank in mind.
* Sat Oct 11 2014 jengelh@inai.de
- Use source URLs
* Thu Sep 12 2013 werner@suse.de
- Make it build with latest TeXLive 2013
* Thu Dec  6 2012 jengelh@inai.de
- Add symlinks that are expected by other programs
* Wed Dec  5 2012 jengelh@inai.de
- Throw out undocumented patches, throw out %%makeinstall
* Tue Sep 27 2011 jengelh@medozas.de
- Initial package (version 0.5) for build.opensuse.org
